@@ -72,6 +72,7 @@ void about_cb(GtkWidget *widget, gpointer data)
 {
     gchar *authors[] = {
 	"Tim P. Gerla",
+	"Icons by Straylight and Tigert",
 	NULL
     };  
 
@@ -83,7 +84,7 @@ void about_cb(GtkWidget *widget, gpointer data)
 	"2.2 (CVS)",
 	"(C) 1997-98 Tim P. Gerla",
 	(const gchar**)authors,
-	_("Gnome CD player application with CDDB support."
+	_("GTCD is the Gnome CD player application. Includes CDDB support."
 	  " Please see the \'Thanks\' file included with the"
 	  " distribution for more credits."),
 	NULL);
@@ -120,12 +121,14 @@ void changer_cb(GtkWidget *widget, gpointer data)
 {
     tcd_change_disc(&cd, GPOINTER_TO_INT(data));
     tcd_post_init(&cd);
+    if(cd.err)
+    	perror("accessing cdrom drive");
     cd.play_method = NORMAL;
     if(cd.isplayable)
     {
+        tcd_readdiskinfo(&cd);
 	make_goto_menu();
 	update_editor();
     }
     return;
 }
-
